import type { Reducer, AnyAction } from 'redux';
import type { CollectionMetadata } from 'mongodb-collection-model';
import type Collection from 'mongodb-collection-model';
import type { ThunkAction } from 'redux-thunk';
import type AppRegistry from 'hadron-app-registry';
import type { DataService } from 'mongodb-data-service';
import React from 'react';
type CollectionThunkAction<ReturnType, Action extends AnyAction = AnyAction> = ThunkAction<ReturnType, CollectionState, {
    globalAppRegistry: AppRegistry;
    localAppRegistry: AppRegistry;
    dataService: DataService;
}, Action>;
export type CollectionStateMetadata = CollectionMetadata & {
    serverVersion: string;
    isAtlas: boolean;
    isDataLake: boolean;
};
export type CollectionState = {
    stats: Pick<Collection, 'document_count' | 'index_count' | 'index_size' | 'status' | 'avg_document_size' | 'storage_size' | 'free_storage_size'> | null;
    metadata: CollectionStateMetadata;
    currentTab: 'Documents' | 'Aggregations' | 'Schema' | 'Indexes' | 'Validation';
    initialQuery?: unknown;
    initialAggregation?: unknown;
    initialPipelineText?: unknown;
    editViewName?: string;
};
export declare function pickCollectionStats(collection: Collection): CollectionState['stats'];
declare enum CollectionActions {
    CollectionStatsFetched = "compass-collection/CollectionStatsFetched",
    CollectionMetadataFetched = "compass-collection/CollectionMetadataFetched",
    ChangeTab = "compass-collection/ChangeTab"
}
declare const reducer: Reducer<CollectionState>;
export declare const collectionStatsFetched: (collection: Collection) => {
    type: CollectionActions;
    collection: Collection;
};
export declare const collectionMetadataFetched: (metadata: CollectionMetadata) => {
    type: CollectionActions;
    metadata: CollectionMetadata;
};
export declare const selectTab: (tabName: CollectionState['currentTab']) => CollectionThunkAction<void>;
export declare const selectDatabase: () => CollectionThunkAction<void>;
export declare const editView: () => CollectionThunkAction<void>;
export declare const returnToView: () => CollectionThunkAction<void>;
export declare const renderScopedModals: () => CollectionThunkAction<React.ReactElement[]>;
export declare const renderTabs: () => CollectionThunkAction<{
    name: string;
    component: React.ReactElement;
}[]>;
export default reducer;
//# sourceMappingURL=collection-tab.d.ts.map