import React from 'react';
import type { AnyAction, Reducer } from 'redux';
import type { ThunkAction } from 'redux-thunk';
import AppRegistry from 'hadron-app-registry';
import type { CollectionMetadata } from 'mongodb-collection-model';
import type { DataService } from 'mongodb-data-service';
export type CollectionTab = {
    id: string;
    namespace: string;
    type: string;
    selectedSubTabName: string;
    localAppRegistry: AppRegistry;
    component: React.ReactElement;
};
export type CollectionTabsState = {
    tabs: CollectionTab[];
    activeTabId: string | null;
};
declare enum CollectionTabsActions {
    OpenCollection = "compass-collection/OpenCollection",
    OpenCollectionInNewTab = "compass-collection/OpenCollectionInNewTab",
    SelectTab = "compass-collection/SelectTab",
    MoveTab = "compass-collection/MoveTab",
    SelectPreviousTab = "compass-collection/SelectPreviousTab",
    SelectNextTab = "compass-collection/SelectNextTab",
    CloseTab = "compass-collection/CloseTab",
    SubtabChanged = "compass-colection/SubtabChanged",
    CollectionDropped = "compass-collection/CollectionDropped",
    DatabaseDropped = "compass-collection/DatabaseDropped",
    DataServiceConnected = "compass-collection/DataServiceConnected",
    DataServiceDisconnected = "compass-collection/DataServiceDisconnected"
}
type CollectionTabsThunkAction<ReturnType, Action extends AnyAction = AnyAction> = ThunkAction<ReturnType, CollectionTabsState, {
    globalAppRegistry: AppRegistry;
    dataService: DataService | null;
}, Action>;
declare const reducer: Reducer<CollectionTabsState>;
export declare const openCollectionInNewTab: (collectionMetadata: CollectionMetadata) => CollectionTabsThunkAction<void>;
export declare const openCollection: (collectionMetadata: CollectionMetadata) => CollectionTabsThunkAction<void>;
export declare const selectTabByIndex: (index: number) => CollectionTabsThunkAction<void>;
export declare const selectPreviousTab: () => CollectionTabsThunkAction<void>;
export declare const selectNextTab: () => CollectionTabsThunkAction<void>;
export declare const moveTabByIndex: (fromIndex: number, toIndex: number) => CollectionTabsThunkAction<void>;
export declare const closeTabAtIndex: (index: number) => CollectionTabsThunkAction<void>;
export declare const getActiveTabIndex: (state: CollectionTabsState) => number;
export declare const getActiveTab: (state: CollectionTabsState) => CollectionTab | null;
export declare const openNewTabForCurrentCollection: () => CollectionTabsThunkAction<void>;
export declare const collectionDropped: (namespace: string) => CollectionTabsThunkAction<void>;
export declare const databaseDropped: (namespace: string) => CollectionTabsThunkAction<void>;
export declare const dataServiceConnected: () => {
    type: CollectionTabsActions;
};
export declare const dataServiceDisconnected: () => {
    type: CollectionTabsActions;
};
export default reducer;
//# sourceMappingURL=tabs.d.ts.map